@@ -35,6 +35,8 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
+#define ERROR                      -1
+
 #define NXBOOT_PRIMARY_SLOT_NUM   (0)
 #define NXBOOT_SECONDARY_SLOT_NUM (1)
 #define NXBOOT_TERTIARY_SLOT_NUM  (2)
@@ -117,6 +119,7 @@ struct nxboot_img_header
 
   struct nxboot_img_version img_version; /* Image version */
 };
+
 static_assert(CONFIG_NXBOOT_HEADER_SIZE > sizeof(struct nxboot_img_header),
               "CONFIG_NXBOOT_HEADER_SIZE has to be larger than"
               "sizeof(struct nxboot_img_header)");
@@ -131,10 +134,46 @@ struct nxboot_state
   enum nxboot_update_type next_boot;  /* nxboot_update_type with next operation */
 };
 
+enum progress_type_e
+{
+  nxboot_info = 0,         /* Prefixes arg. string with "INFO:" */
+  nxboot_error,            /* Prefixes arg. string with "ERR:" */
+  nxboot_progress_start,   /* Prints arg. string with no newline to allow ..... sequence to follow */
+  nxboot_progress_dot,     /* Prints of a "." to the ..... progress sequence */
+  nxboot_progress_percent, /* Displays progress as % remaining */
+  nxboot_progress_end,     /* Flags end of a "..." progrees sequence and prints newline */
+};
+
+enum progress_msg_e
+{
+  startup_msg              = 0,
+  power_reset,
+  soft_reset,
+  found_bootable_image,
+  no_bootable_image,
+  boardioc_image_boot_fail,
+  ramcopy_started,
+  recovery_revert,
+  recovery_create,
+  update_from_update,
+  validate_primary,
+  validate_recovery,
+  validate_update,
+  recovery_created,
+  recovery_invalid,
+  update_failed,
+};
+
 /****************************************************************************
  * Public Function Prototypes
  ****************************************************************************/
 
+#ifdef CONFIG_NXBOOT_PROGRESS
+void nxboot_progress(enum progress_type_e type, ...);
+#else
+#define nxboot_progress(type, ...) do {} while (0)
+#endif
+
 /****************************************************************************
  * Name: nxboot_get_state
  *
@@ -148,7 +187,7 @@ struct nxboot_state
  *   state: The pointer to nxboot_state structure. The state is stored here.
  *
  * Returned Value:
- *   0 on success, -1 and sets errno on failure.
+ *   OK (0) on success, ERROR (-1) and sets errno on failure.
  *
  ****************************************************************************/
 
@@ -164,7 +203,7 @@ int nxboot_get_state(struct nxboot_state *state);
  *   if afterwards.
  *
  * Returned Value:
- *   Valid file descriptor on success, -1 and sets errno on failure.
+ *   Valid file descriptor on success, ERROR (-1) and sets errno on failure.
  *
  ****************************************************************************/
 
@@ -180,7 +219,7 @@ int nxboot_open_update_partition(void);
  *   state of the bootloader.
  *
  * Returned Value:
- *   1 means confirmed, 0 not confirmed, -1 and sets errno on failure.
+ *   1 if confirmed, OK (0) on success, ERROR (-1) and sets errno on failure.
  *
  ****************************************************************************/
 
@@ -194,14 +233,14 @@ int nxboot_get_confirm(void);
  *   its copy in update partition as a recovery.
  *
  * Returned Value:
- *   0 on success, -1 and sets errno on failure.
+ *   OK (0) on success, ERROR (-1) and sets errno on failure.
  *
  ****************************************************************************/
 
 int nxboot_confirm(void);
 
 /****************************************************************************
- * Name: nxboot_perform_swap
+ * Name: nxboot_perform_update
  *
  * Description:
  *   Checks for the possible firmware update and performs it by copying
@@ -216,10 +255,29 @@ int nxboot_confirm(void);
  *   check_only: Only repairs corrupted update, but do not start another one
  *
  * Returned Value:
- *   0 on success, -1 and sets errno on failure.
+ *   OK (0) on success, ERROR (-1) and sets errno on failure.
  *
  ****************************************************************************/
 
 int nxboot_perform_update(bool check_only);
 
+/****************************************************************************
+ * Name: nxboot_ramcopy
+ *
+ * Description:
+ *   Copies the (already) validate bootable image to RAM memory
+ *
+ *   NOTE - no checking that the RAM location is correct, nor that the
+ *          image size is appropriate for that RAM address!
+ *
+ * Input parameters:
+ *   none
+ *
+ * Returned Value:
+ *   OK (0) on success, ERROR (-1) on fail
+ *
+ ****************************************************************************/
+
+int nxboot_ramcopy(void);
+
 #endif /* __BOOT_NXBOOT_INCLUDE_NXBOOT_H */
