@@ -48,7 +48,12 @@ void mbedtls_sha1_free(FAR mbedtls_sha1_context *ctx)
 int mbedtls_sha1_starts(FAR mbedtls_sha1_context *ctx)
 {
   ctx->session.mac = CRYPTO_SHA1;
-  return cryptodev_get_session(ctx);
+  if (cryptodev_get_session(ctx) != 0)
+    {
+      return MBEDTLS_ERR_SHA1_BAD_INPUT_DATA;
+    }
+
+  return 0;
 }
 
 int mbedtls_sha1_update(FAR mbedtls_sha1_context *ctx,
@@ -59,7 +64,12 @@ int mbedtls_sha1_update(FAR mbedtls_sha1_context *ctx,
   ctx->crypt.flags |= COP_FLAG_UPDATE;
   ctx->crypt.src = (caddr_t)input;
   ctx->crypt.len = ilen;
-  return cryptodev_crypt(ctx);
+  if (cryptodev_crypt(ctx) != 0)
+    {
+      return MBEDTLS_ERR_SHA1_BAD_INPUT_DATA;
+    }
+
+  return 0;
 }
 
 int mbedtls_sha1_finish(FAR mbedtls_sha1_context *ctx,
@@ -71,6 +81,11 @@ int mbedtls_sha1_finish(FAR mbedtls_sha1_context *ctx,
   ctx->crypt.flags = 0;
   ctx->crypt.mac = (caddr_t)output;
   ret = cryptodev_crypt(ctx);
+  if (ret != 0)
+    {
+      ret = MBEDTLS_ERR_SHA1_BAD_INPUT_DATA;
+    }
+
   cryptodev_free_session(ctx);
   return ret;
 }
