@@ -310,7 +310,7 @@ int main(int argc, FAR char *argv[])
           if (nsamples * sizeof(struct adc_msg_s) != nbytes)
             {
               printf("adc_main: read size=%ld is not a multiple of "
-                     "sample size=%d, Ignoring\n",
+                     "sample size=%zu, Ignoring\n",
                      (long)nbytes, sizeof(struct adc_msg_s));
             }
           else
