@@ -1,6 +1,8 @@
 /****************************************************************************
  * apps/examples/foc/foc_thr.h
  *
+ * SPDX-License-Identifier: Apache-2.0
+ *
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.  The
@@ -112,7 +114,7 @@ enum foc_controller_state_e
 struct foc_ctrl_env_s
 {
   mqd_t                     mqd;   /* Control msg queue */
-  int                       id;    /* FOC device id */
+  uint8_t                   id;    /* FOC device id */
   int                       inst;  /* Type specific instance counter */
   int                       type;  /* Controller type */
   FAR struct foc_thr_cfg_s *cfg;   /* Control thread configuration */
