@@ -99,11 +99,14 @@ int main(int argc, FAR char *argv[])
 
               if (minmea_parse_rmc(&frame, line))
                 {
-                  printf("Fixed-point Latitude...........: %d\n",
+                  printf("Fixed-point Latitude...........: %" PRIdLEAST32
+                         "\n",
                          minmea_rescale(&frame.latitude, 1000));
-                  printf("Fixed-point Longitude..........: %d\n",
+                  printf("Fixed-point Longitude..........: %" PRIdLEAST32
+                         "\n",
                          minmea_rescale(&frame.longitude, 1000));
-                  printf("Fixed-point Speed..............: %d\n",
+                  printf("Fixed-point Speed..............: %" PRIdLEAST32
+                         "\n",
                          minmea_rescale(&frame.speed, 1000));
                   printf("Floating point degree latitude.: %2.6f\n",
                          minmea_tocoord(&frame.latitude));
@@ -127,7 +130,8 @@ int main(int argc, FAR char *argv[])
                 {
                   printf("Fix quality....................: %d\n",
                          frame.fix_quality);
-                  printf("Altitude.......................: %d\n",
+                  printf("Altitude.......................: %" PRIdLEAST32
+                         "\n",
                          frame.altitude.value);
                   printf("Tracked satellites.............: %d\n",
                          frame.satellites_tracked);
