@@ -1,15 +1,11 @@
 /****************************************************************************
  * apps/examples/xmlrpc/xmlrpc_main.c
  *
- *   Copyright (C) 2012 Max Holtzberg. All rights reserved.
- *   Copyright (C) 2015 Gregory Nutt. All rights reserved.
- *   Author: Max Holtzberg <mh@uvc.de>
- *
- * Based on the embeddable lightweight XML-RPC server code discussed
- * in the article at: http://www.drdobbs.com/web-development/\
- *    an-embeddable-lightweight-xml-rpc-server/184405364
- *
- *  Copyright (c) 2002 Cogito LLC.  All rights reserved.
+ * SPDX-License-Identifier: BSD-3-Clause
+ * SPDX-FileCopyrightText: 2012 Max Holtzberg. All rights reserved.
+ * SPDX-FileCopyrightText: 2015 Gregory Nutt. All rights reserved.
+ * SPDX-FileCopyrightText: 2002 Cogito LLC.  All rights reserved.
+ * SPDX-FileContributor: Max Holtzberg <mh@uvc.de>
  *
  *  Redistribution and use in source and binary forms, with or
  *  without modification, is hereby granted without fee provided
@@ -41,6 +37,10 @@
  * POSSIBILITY OF SUCH DAMAGE.
  ****************************************************************************/
 
+/* Based on the embeddable lightweight XML-RPC server code discussed
+ * in the article at: http://www.drdobbs.com/web-development/\
+ *    an-embeddable-lightweight-xml-rpc-server/184405364
+ */
 /* Lightweight Embedded XML-RPC Server main
  *
  * mtj@cogitollc.com
@@ -410,7 +410,8 @@ int main(int argc, FAR char *argv[])
   for (; ; )
     {
       clilen = sizeof(cliaddr);
-      connfd = accept(listenfd, (struct sockaddr *)&cliaddr, &clilen);
+      connfd = accept4(listenfd, (struct sockaddr *)&cliaddr, &clilen,
+                       SOCK_CLOEXEC);
       if (connfd <= 0)
         {
           break;
