@@ -79,8 +79,12 @@ typedef enum
 
 void vMBPortEnterCritical(void);
 void vMBPortExitCritical(void);
+#ifndef CONFIG_MODBUS_DISABLE_LOG
 void vMBPortLog(eMBPortLogLevel eLevel, const char *szModule,
                 const char *szFmt, ...) printf_like(3, 4);
+#else
+#  define vMBPortLog(l, m, c, ...)
+#endif
 void vMBPortTimerPoll(void);
 bool xMBPortSerialPoll(void);
 bool xMBPortSerialSetTimeout(uint32_t dwTimeoutMs);
