@@ -315,7 +315,7 @@ static lesp_socket_t *get_sock(int sockfd)
   if (((unsigned int)sockfd) >= SOCKET_NBR)
     {
       errno = EINVAL;
-      ninfo("Esp8266 invalid sockfd\n", sockfd);
+      ninfo("Esp8266 invalid sockfd %d\n", sockfd);
       return NULL;
     }
 
@@ -1123,6 +1123,7 @@ static int lesp_parse_cwjap_ans_line(char *ptr, lesp_ap_t *ap)
  *    "FreeWifi" => ssid
  *    -90 => rssi
  *    "00:07:cb:07:b6:00" => mac
+ *    1 => channel
  *
  *   Note: Content of ptr is modified and string in ap point into ptr string.
  *
@@ -1220,6 +1221,14 @@ static int lesp_parse_cwlap_ans_line(char *ptr, lesp_ap_t *ap)
                     }
                 }
               break;
+
+          case 5:
+                {
+                  int i = atoi(ptr);
+
+                  ap->channel = i;
+                }
+              break;
         }
 
       ptr = ptr_next + 1;
@@ -1522,6 +1531,70 @@ int lesp_initialize(void)
   return 0;
 }
 
+/****************************************************************************
+ * Name: lesp_finalize
+ *
+ * Description:
+ *   finalize Esp8266 class.
+ *      - destroy worker thread
+ *      - close port
+ *
+ * Input Parameters:
+ *   None
+ *
+ * Returned Value:
+ *   0 on success, -1 in case of error.
+ *
+ ****************************************************************************/
+
+int lesp_finalize(void)
+{
+  int i;
+
+  ninfo("Finalizing Esp8266...\n");
+
+  pthread_mutex_lock(&g_lesp_state.mutex);
+
+  if (!g_lesp_state.is_initialized)
+    {
+      pthread_mutex_unlock(&g_lesp_state.mutex);
+      ninfo("Esp8266 already finalized\n");
+      return 0;
+    }
+
+  pthread_mutex_lock(&g_lesp_state.worker.mutex);
+
+  for (i = 0; i < SOCKET_NBR; i++)
+    {
+      if ((g_lesp_state.sockets[i].flags & FLAGS_SOCK_USED) != 0)
+        {
+          nerr("ERROR: Exist opened socket\n");
+          pthread_mutex_unlock(&g_lesp_state.worker.mutex);
+          pthread_mutex_unlock(&g_lesp_state.mutex);
+          return -1;
+        }
+    }
+
+  /* Destroy worker thread */
+
+  g_lesp_state.worker.running = false;
+  pthread_kill(g_lesp_state.worker.thread, SIGTERM);
+  pthread_join(g_lesp_state.worker.thread, NULL);
+
+  if (g_lesp_state.fd > 0)
+    {
+       close(g_lesp_state.fd);
+       g_lesp_state.fd = -1;
+    }
+
+  g_lesp_state.is_initialized = false;
+
+  pthread_mutex_unlock(&g_lesp_state.worker.mutex);
+  pthread_mutex_unlock(&g_lesp_state.mutex);
+
+  return 0;
+}
+
 /****************************************************************************
  * Name: lesp_soft_reset
  *
@@ -1771,7 +1844,7 @@ int lesp_get_net(lesp_mode_t mode, in_addr_t *ip,
     {
       ninfo("Read:%s\n", g_lesp_state.bufans);
 
-      ret = lesp_parse_cipxxx_ans_line(g_lesp_state.bufans, mask);
+      ret = lesp_parse_cipxxx_ans_line(g_lesp_state.bufans, gw);
       if (ret < 0)
         {
           nerr("ERROR: Line badly formed.\n");
@@ -2179,7 +2252,7 @@ int lesp_socket(int domain, int type, int protocol)
  *   close socket creates with lesp_socket.
  *
  * Input Parameters:
- *   sockfd   : socket indentifer.
+ *   sockfd    Socket descriptor returned by socket()
  *
  * Returned Value:
  *   A 0 on success; -1 on error.
@@ -2283,7 +2356,7 @@ int lesp_connect(int sockfd, FAR const struct sockaddr *addr,
                  socklen_t addrlen)
 {
   int ret = 0;
-  const char *proto_str;
+  const char *proto_str = "";
   lesp_socket_t *sock;
   struct sockaddr_in *in;
   unsigned short port;
