@@ -1,14 +1,13 @@
 /****************************************************************************
  * apps/netutils/thttpd/thttpd_cgi.c
- * CGI support
  *
- *   Copyright (C) 2009, 2011, 2016 Gregory Nutt. All rights reserved.
- *   Author: Gregory Nutt <gnutt@nuttx.org>
- *
- * Derived from the file libhttpd.c in the original THTTPD package:
- *
- *   Copyright © 1995,1998,1999,2000,2001 by
- *   Jef Poskanzer <jef@mail.acme.com>. All rights reserved.
+ * SPDX-License-Identifier: BSD-2-Clause
+ * SPDX-FileCopyrightText: 2011, 2016 Gregory Nutt. All rights reserved.
+ * SPDX-FileCopyrightText: 2009 Gregory Nutt. All rights reserved.
+ * SPDX-FileCopyrightText: 2000, 2001 by Jef Poskanzer <jef@mail.acme.com>.
+ * SPDX-FileCopyrightText: 1998, 1999 by Jef Poskanzer <jef@mail.acme.com>.
+ * SPDX-FileCopyrightText: 1995 by Jef Poskanzer <jef@mail.acme.com>.
+ * SPDX-FileContributor: Gregory Nutt <gnutt@nuttx.org>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -717,7 +716,7 @@ static int cgi_child(int argc, char **argv)
 {
   FAR httpd_conn *hc = (FAR httpd_conn *)strtoul(argv[1], NULL, 16);
 #if CONFIG_THTTPD_CGI_TIMELIMIT > 0
-  ClientData client_data;
+  clientdata client_data;
 #endif
   FAR char **argp;
   FAR struct cgi_conn_s *cc;
@@ -1096,7 +1095,7 @@ errout_with_sem:
 }
 
 #if CONFIG_THTTPD_CGI_TIMELIMIT > 0
-static void cgi_kill(ClientData client_data, struct timeval *nowp)
+static void cgi_kill(clientdata client_data, struct timeval *nowp)
 {
   pid_t pid = (pid_t)client_data.i;
 
