@@ -152,6 +152,12 @@ struct nsh_vtbl_s
   /* Ctrl tty or not */
 
   bool isctty;
+
+  /* Current working directory */
+
+#ifdef CONFIG_DISABLE_ENVIRON
+  char cwd[PATH_MAX];
+#endif
 };
 
 /* This structure describes a console front-end that is based on stdin and
@@ -182,7 +188,7 @@ struct console_stdio_s
 
   /* Line input buffer */
 
-  char   cn_line[CONFIG_NSH_LINELEN];
+  char   cn_line[LINE_MAX];
 };
 
 /****************************************************************************
