@@ -26,6 +26,7 @@
 
 #include <nuttx/config.h>
 
+#include <stdio.h>
 #include <string.h>
 
 #include "nsh.h"
@@ -58,33 +59,45 @@ int cmd_free(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
 
 int cmd_memdump(FAR struct nsh_vtbl_s *vtbl, int argc, FAR char **argv)
 {
-  char arg[CONFIG_NSH_LINELEN] = "";
+  FAR char *arg;
   int i;
 
+  arg = lib_get_tempbuffer(LINE_MAX);
+  if (arg == NULL)
+    {
+      return -ENOMEM;
+    }
+
+  arg[0] = '\0';
+
   if (argc == 1)
     {
-      strlcpy(arg, "used", CONFIG_NSH_LINELEN);
+      strlcpy(arg, "used", LINE_MAX);
     }
   else if (argc >= 2 && (strcmp(argv[1], "-h") == 0 ||
                          strcmp(argv[1], "help") == 0))
     {
-      return nsh_catfile(vtbl, argv[0],
-                         CONFIG_NSH_PROC_MOUNTPOINT "/memdump");
+      i = nsh_catfile(vtbl, argv[0],
+                      CONFIG_NSH_PROC_MOUNTPOINT "/memdump");
+      lib_put_tempbuffer(arg);
+      return i;
     }
   else
     {
       for (i = 1; i < argc; i++)
         {
-          strlcat(arg, argv[i], CONFIG_NSH_LINELEN);
+          strlcat(arg, argv[i], LINE_MAX);
           if (i < argc - 1)
             {
-              strlcat(arg, " ", CONFIG_NSH_LINELEN);
+              strlcat(arg, " ", LINE_MAX);
             }
         }
     }
 
-  return nsh_writefile(vtbl, argv[0], arg, strlen(arg),
-                       CONFIG_NSH_PROC_MOUNTPOINT "/memdump");
+  i = nsh_writefile(vtbl, argv[0], arg, strlen(arg),
+                    CONFIG_NSH_PROC_MOUNTPOINT "/memdump");
+  lib_put_tempbuffer(arg);
+  return i;
 }
 
 #endif /* !CONFIG_NSH_DISABLE_MEMDUMP && NSH_HAVE_WRITEFILE */
