@@ -502,6 +502,8 @@ static int nsh_execute(FAR struct nsh_vtbl_s *vtbl,
                        int argc, FAR char *argv[],
                        FAR const struct nsh_param_s *param)
 {
+  int fd_out = STDOUT_FILENO;
+  int fd_in = STDIN_FILENO;
   int ret;
 
   /* DO NOT CHANGE THE ORDERING OF THE FOLLOWING STEPS
@@ -605,15 +607,23 @@ static int nsh_execute(FAR struct nsh_vtbl_s *vtbl,
     {
       FAR char *sh_argv[4];
       FAR char *sh_cmd = "sh";
-      char sh_arg2[CONFIG_NSH_LINELEN];
+      FAR char *sh_arg2;
 
       DEBUGASSERT(strncmp(argv[0], sh_cmd, 3) != 0);
 
+      sh_arg2 = lib_get_tempbuffer(LINE_MAX);
+      if (sh_arg2 == NULL)
+        {
+          nsh_error(vtbl, g_fmtcmdoutofmemory, sh_cmd);
+          ret = -errno;
+          goto close_redir;
+        }
+
       sh_arg2[0] = '\0';
 
       for (ret = 0; ret < argc; ret++)
         {
-          strlcat(sh_arg2, argv[ret], sizeof(sh_arg2));
+          strlcat(sh_arg2, argv[ret], LINE_MAX);
 
           if (ret < argc - 1)
             {
@@ -630,16 +640,15 @@ static int nsh_execute(FAR struct nsh_vtbl_s *vtbl,
        * dispatch the backgroud by sh -c ""
        */
 
-      return nsh_execute(vtbl, 4, sh_argv, param);
+      ret = nsh_execute(vtbl, 4, sh_argv, param);
+      lib_put_tempbuffer(sh_arg2);
+      return ret;
     }
   else
 #endif
     {
       uint8_t save[SAVE_SIZE];
 
-      int fd_in = STDIN_FILENO;
-      int fd_out = STDOUT_FILENO;
-
       /* Redirected output? */
 
       if (vtbl->np.np_redir_out)
@@ -657,7 +666,8 @@ static int nsh_execute(FAR struct nsh_vtbl_s *vtbl,
                 {
                   nsh_error(vtbl, g_fmtcmdfailed, argv[0], "open",
                             NSH_ERRNO);
-                  return nsh_saveresult(vtbl, true);
+                  ret = errno;
+                  goto close_redir;
                 }
             }
           else
@@ -683,7 +693,8 @@ static int nsh_execute(FAR struct nsh_vtbl_s *vtbl,
                 {
                   nsh_error(vtbl, g_fmtcmdfailed, argv[0], "open",
                             NSH_ERRNO);
-                  return nsh_saveresult(vtbl, true);
+                  ret = errno;
+                  goto close_redir;
                 }
             }
           else
@@ -716,22 +727,27 @@ static int nsh_execute(FAR struct nsh_vtbl_s *vtbl,
         {
           nsh_undirect(vtbl, save);
         }
+    }
 
-      /* Mark errors so that it is possible to test for non-zero return
-       * values in nsh scripts.
-       */
+close_redir:
 
-      if (ret < 0)
-        {
-          return nsh_saveresult(vtbl, true);
-        }
+  /* Closing fds opened for redirection if necessary */
+
+  if (fd_out > STDOUT_FILENO)
+    {
+      close(fd_out);
+    }
+
+  if (fd_in > STDIN_FILENO)
+    {
+      close(fd_in);
     }
 
   /* Return success if the command succeeded (or at least, starting of the
    * command task succeeded).
    */
 
-  return nsh_saveresult(vtbl, false);
+  return nsh_saveresult(vtbl, ret != OK);
 }
 
 /****************************************************************************
@@ -2456,7 +2472,7 @@ static int nsh_parse_command(FAR struct nsh_vtbl_s *vtbl, FAR char *cmdline)
 #endif
 
 #ifdef CONFIG_SCHED_INSTRUMENTATION_DUMP
-  char      tracebuf[CONFIG_NSH_LINELEN + 1];
+  char      tracebuf[LINE_MAX + 1];
 
   strlcpy(tracebuf, cmdline, sizeof(tracebuf));
   sched_note_beginex(NOTE_TAG_APP, tracebuf);
@@ -2679,7 +2695,7 @@ static int nsh_parse_command(FAR struct nsh_vtbl_s *vtbl, FAR char *cmdline)
         {
           FAR char *arg;
           FAR char *sh_argv[4];
-          char sh_arg2[CONFIG_NSH_LINELEN];
+          FAR char *sh_arg2;
 
           if (argv[argc][g_pipeline1_len])
             {
@@ -2697,11 +2713,19 @@ static int nsh_parse_command(FAR struct nsh_vtbl_s *vtbl, FAR char *cmdline)
               goto dynlist_free;
             }
 
+          sh_arg2 = lib_get_tempbuffer(LINE_MAX);
+          if (sh_arg2 == NULL)
+            {
+              nsh_error(vtbl, g_fmtcmdoutofmemory, cmd);
+              ret = -errno;
+              goto dynlist_free;
+            }
+
           sh_arg2[0] = '\0';
 
           for (ret = 0; ret < argc; ret++)
             {
-              strlcat(sh_arg2, argv[ret], sizeof(sh_arg2));
+              strlcat(sh_arg2, argv[ret], LINE_MAX);
 
               if (ret < argc - 1)
                 {
@@ -2717,6 +2741,7 @@ static int nsh_parse_command(FAR struct nsh_vtbl_s *vtbl, FAR char *cmdline)
           ret = pipe2(pipefd, 0);
           if (ret < 0)
             {
+              lib_put_tempbuffer(sh_arg2);
               ret = -errno;
               goto dynlist_free;
             }
@@ -2729,22 +2754,19 @@ static int nsh_parse_command(FAR struct nsh_vtbl_s *vtbl, FAR char *cmdline)
           vtbl->np.np_bg = true;
 
           ret = nsh_execute(vtbl, 4, sh_argv, &param);
+          lib_put_tempbuffer(sh_arg2);
 
           vtbl->np.np_bg = bg_save;
 
           if (param.fd_in != -1)
             {
               close(param.fd_in);
-              param.fd_in = -1;
               vtbl->np.np_redir_in = redirect_in_save;
             }
 
-          if (param.fd_out != -1)
-            {
-              close(param.fd_out);
-              param.fd_out = -1;
-              vtbl->np.np_redir_out = redirect_out_save;
-            }
+          close(param.fd_out);
+          param.fd_out = -1;
+          vtbl->np.np_redir_out = redirect_out_save;
 
           redirect_in_save = vtbl->np.np_redir_in;
           vtbl->np.np_redir_in = true;
