@@ -281,7 +281,7 @@ void nxevent_test(void)
 
   /* Lower priority */
 
-  sparam.sched_priority = PTHREAD_DEFAULT_PRIORITY - 1;
+  sparam.sched_priority = PTHREAD_DEFAULT_PRIORITY;
   pthread_attr_setschedparam(&attr, &sparam);
 
   /* Create thread */
@@ -304,7 +304,7 @@ void nxevent_test(void)
 
   /* Lower priority */
 
-  sparam.sched_priority = PTHREAD_DEFAULT_PRIORITY - 1;
+  sparam.sched_priority = PTHREAD_DEFAULT_PRIORITY;
   pthread_attr_setschedparam(&attr, &sparam);
 
   /* Create thread */
