@@ -30,7 +30,6 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
-#include <fcntl.h>
 #include <syslog.h>
 #include <stdint.h>
 #include <stdarg.h>
@@ -259,7 +258,7 @@ void test_nuttx_fs_stream03(FAR void **state)
   char *junk = "abcdefghijklmnopqrstuvwxyz";
   size_t len = strlen(junk);
   char *inbuf = NULL;
-  int ret;
+  ssize_t ret;
   int lc;
   for (lc = 0; lc < 10; lc++)
     {
@@ -276,9 +275,9 @@ void test_nuttx_fs_stream03(FAR void **state)
           assert_true(1 == 0);
         }
 
-      if ((size_t)ret != len)
+      if (ret != len)
         {
-          syslog(LOG_ERR, "len = %zu != return value from fwrite = %d",
+          syslog(LOG_ERR, "len = %zu != return value from fwrite = %zd",
                  len, ret);
           fclose(stream);
           assert_true(1 == 0);
@@ -308,9 +307,9 @@ void test_nuttx_fs_stream03(FAR void **state)
           assert_true(1 == 0);
         }
 
-      if ((size_t)ret != len)
+      if (ret != len)
         {
-          syslog(LOG_ERR, "len = %zu != return value from fread = %d",
+          syslog(LOG_ERR, "len = %zu != return value from fread = %zd",
                  len, ret);
           free(inbuf);
           fclose(stream);
